==> h-orm-0.1.8-sources.jar: cn/sylinx/horm/proxy/mapper/parse/SqlItem.java <==
package cn.sylinx.horm.proxy.mapper.parse;

public class SqlItem {

    private String namespaceId; // 命名空间，对应dao mapper

    private String sqlId; // sqlId

    private SqlType sqlType; // sql类型

    private String datasource; // 数据源

    private String statement; // sql语句

    private boolean retrieval = false; // 插入是否返回主键

    public String getNamespaceId() {
        return namespaceId;
    }

    public void setNamespaceId(String namespaceId) {
        this.namespaceId = namespaceId;
    }

    public String getSqlId() {
        return sqlId;
    }

    public void setSqlId(String sqlId) {
        this.sqlId = sqlId;
    }

    public SqlType getSqlType() {
        return sqlType;
    }

    public void setSqlType(SqlType sqlType) {
        this.sqlType = sqlType;
    }

    public String getDatasource() {
        return datasource;
    }

    public void setDatasource(String datasource) {
        this.datasource = datasource;
    }

    public String getStatement() {
        return statement;
    }

    public void setStatement(String statement) {
        this.statement = statement;
    }

    public boolean isRetrieval() {
        return retrieval;
    }

    public void setRetrieval(boolean retrieval) {
        this.retrieval = retrieval;
    }

    @Override
    public String toString() {
        return "SqlItem [namespaceId=" + namespaceId + ", sqlId=" + sqlId + ", sqlType=" + sqlType + ", datasource="
                + datasource + ", statement=" + statement + ", retrieval=" + retrieval + "]";
    }

}

==> h-orm-1.0.8.3-sources.jar: cn/sylinx/horm/proxy/mapper/parse/SqlItem.java <==
package cn.sylinx.horm.proxy.mapper.parse;

public class SqlItem {

    private String namespaceId; // 命名空间，对应dao mapper

    private String sqlId; // sqlId

    private SqlType sqlType; // sql类型

    private String datasource; // 数据源

    private String statement; // sql语句

    private boolean retrieval = false; // 插入是否返回主键
    
    private String parseSqlType;

    public String getNamespaceId() {
        return namespaceId;
    }

    public void setNamespaceId(String namespaceId) {
        this.namespaceId = namespaceId;
    }

    public String getSqlId() {
        return sqlId;
    }

    public void setSqlId(String sqlId) {
        this.sqlId = sqlId;
    }

    public SqlType getSqlType() {
        return sqlType;
    }

    public void setSqlType(SqlType sqlType) {
        this.sqlType = sqlType;
    }

    public String getDatasource() {
        return datasource;
    }

    public void setDatasource(String datasource) {
        this.datasource = datasource;
    }

    public String getStatement() {
        return statement;
    }

    public void setStatement(String statement) {
        this.statement = statement;
    }

    public boolean isRetrieval() {
        return retrieval;
    }

    public void setRetrieval(boolean retrieval) {
        this.retrieval = retrieval;
    }

    public String getParseSqlType() {
        return parseSqlType;
    }

    public void setParseSqlType(String parseSqlType) {
        this.parseSqlType = parseSqlType;
    }

    @Override
    public String toString() {
        return "SqlItem [namespaceId=" + namespaceId + ", sqlId=" + sqlId + ", sqlType=" + sqlType + ", datasource="
                + datasource + ", statement=" + statement + ", retrieval=" + retrieval + ", parseSqlType="
                + parseSqlType + "]";
    }

}
